Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Format ¶
type Format []FormatPart
A Format describes a particular way of representing a record as a string.
func ParseFormat ¶
Creates a Format object that can be used to efficiently read and write records from the given format string.
type FormatPart ¶
Click to show internal directories.
Click to hide internal directories.